
<dl>
<dt><a href="./tcl.py"><code>tcl.py</code></a></dt><dd>
  Interpreter wrapper. Python objects are defined that wrap Tcl interpreters.
</dd>

<dt><a href="./openseespy.py"><code>openseespy.py</code></a></dt><dd>
  OpenSeesPy compatibility layer. Implements the OpenSeesPy API.
</dd>

<dt><code>library/</code></dt><dd>
  Library wrapper. Python objects are defined which serialize into Tcl commands.
</dd>
</dl>

